# fns ![Release](https://github.com/amitness/fns/workflows/Release/badge.svg)
Reusable functions for Machine Learning.


## Installation
Install via [pip](https://pypi.org/project/fns).

```bash
pip install fns
```

## Documentation
The documentation is available [here](https://amitness.com/fns/).